==> billogram-foundation-3.4.0.tgz: package/modules/components/dropdown/DropdownState.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import { dropdownOptionsShape } from './utils/propTypes';
import getHighlightedIndex from './utils/getHighlightedIndex';


export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    return React.createClass({

        displayName: `${Component.displayName}State`,

        mixins: [PureRenderMixin],

        propTypes: {
            options: dropdownOptionsShape,
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                options: [],
                value: ''
            };
        },

        getInitialState() {
            return {
                expanded: false,
                highlightedIndex: -1
            };
        },

        onCollapse() {
            this.setState({
                expanded: false,
                highlightedIndex: -1
            });
        },

        onExpand() {
            const { options, value } = this.props;
            const highlightedIndex = getHighlightedIndex({ options, value });

            this.setState({
                expanded: true,
                highlightedIndex
            });
        },

        onHighlightedIndexChange(highlightedIndex) {
            this.setState({
                highlightedIndex
            });
        },

        render() {
            return (
                <Component
                    { ...this.props }
                    { ...this.state }
                    onCollapse={ this.onCollapse }
                    onExpand={ this.onExpand }
                    onHighlightedIndexChange={ this.onHighlightedIndexChange } />
            );
        }

    });

};

==> billogram-foundation-3.5.0.tgz: package/modules/components/dropdown/DropdownState.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import { dropdownOptionsShape } from './utils/propTypes';
import getHighlightedIndex from './utils/getHighlightedIndex';


export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    return React.createClass({

        displayName: `${Component.displayName}State`,

        mixins: [PureRenderMixin],

        propTypes: {
            options: dropdownOptionsShape,
            value: PropTypes.any
        },

        getDefaultProps() {
            return {
                options: [],
                value: ''
            };
        },

        getInitialState() {
            return {
                expanded: false,
                highlightedIndex: -1
            };
        },

        onCollapse() {
            this.setState({
                expanded: false,
                highlightedIndex: -1
            });
        },

        onExpand() {
            const { options, value } = this.props;
            const highlightedIndex = getHighlightedIndex({ options, value });

            this.setState({
                expanded: true,
                highlightedIndex
            });
        },

        onHighlightedIndexChange(highlightedIndex) {
            this.setState({
                highlightedIndex
            });
        },

        render() {
            return (
                <Component
                    { ...this.props }
                    { ...this.state }
                    onCollapse={ this.onCollapse }
                    onExpand={ this.onExpand }
                    onHighlightedIndexChange={ this.onHighlightedIndexChange } />
            );
        }

    });

};
